#
# spec file for package fastjet
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fastjet
Version:        3.2.1
Release:        lp150.1.7
Summary:        Package for jet finding in pp and e+e- collisions
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://fastjet.fr/
Source:         http://fastjet.fr/repo/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation. 

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

%package -n libfastjet0
Summary:        Shared libraries for fastjet core package
Group:          Development/Libraries/C and C++

%description -n libfastjet0
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation. 

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides the shared libraries for fastjet and its
plugins.


%package -n fastjet-devel
Summary:        Shared libraries for fastjet core package
Group:          Development/Libraries/C and C++
Requires:       libfastjet0 = %{version}

%description -n fastjet-devel
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation. 

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides the header files for development with fastjet.


%package -n fastjet-plugin-siscone
Summary:        SISCone plugin for fastjet
Group:          Development/Libraries/C and C++

%description -n fastjet-plugin-siscone
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation. 

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides shared libraries for SISCone plugin for
fastjet.


%package -n fastjet-plugin-siscone-devel
Summary:        SISCone plugin for fastjet
Group:          Development/Libraries/C and C++
Requires:       fastjet-devel = %{version}
Requires:       fastjet-plugin-siscone = %{version}

%description -n fastjet-plugin-siscone-devel
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation. 

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides the develoment files for SISCone plugin for
fastjet.

%prep
%setup -q

%build
%configure --disable-static --enable-allcxxplugins
make %{?_smp_mflags}

%install
%make_install

# REMOVE libtool ARCHIVES
rm %{buildroot}%{_libdir}/*.la

%post -n libfastjet0 -p /sbin/ldconfig

%postun -n libfastjet0 -p /sbin/ldconfig

%post -n fastjet-plugin-siscone -p /sbin/ldconfig

%postun -n fastjet-plugin-siscone -p /sbin/ldconfig

%files -n libfastjet0
%defattr(-,root,root)
%doc ChangeLog README COPYING
%{_libdir}/libfastjet.so.*
%{_libdir}/libfastjettools.so.*
%{_libdir}/libfastjetplugins.so.*

%files -n fastjet-devel
%defattr(-,root,root)
%{_bindir}/fastjet-config
%{_libdir}/libfastjet.so
%{_libdir}/libfastjettools.so
%{_libdir}/libfastjetplugins.so
%{_includedir}/fastjet/

%files -n fastjet-plugin-siscone
%defattr(-,root,root)
%{_libdir}/libsiscone*.so.*

%files -n fastjet-plugin-siscone-devel
%defattr(-,root,root)
%{_libdir}/libsiscone*.so
%{_includedir}/siscone/

%changelog
* Sat Nov 12 2016 badshah400@gmail.com
- Update to version 3.2.1:
  * Added a missing assignment operator for ClusterSequence.
  * Eliminated a warning about unused variables when assertions
    are disabled.
  * Included SISCone-3.0.3 which now installs config.h to improve
    build stability.
- Changes from version 3.2.0:
  * Exposed the N2Plain and N2Tiled strategies for 3rd-party
    clustering algorithms under the form of two new classes
    (NNFJN2Plain and NNFJN2Tiled), similar to NNH.
  * Included version 3.0.2 SISCone with minor bug fixes.
  * Made template implementation of
    PseudoJet::obj_sorted_by_values() public.
  * Added a --guess-prefix option to fastjet-config (guesses
    prefix from location of fastjet-config instead of prefix from
    configure).
  * Added a --disable-auto-ptr option to configure.
  * Added internal helpers for C++11 and C++14 features:
    compile-time deprecation and the override keyword.
  * Small tweaks to the build system.
  * fjcore now ships with an illustrative fortran wrapper and
    example.
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.1.3
  * disables JetDefinition::operator(...) when CINT is detected, for
    ROOT v5 compatibility
  * works around an issue with recent versions of CGAL and the clang
    compiler
- Changes from version 3.1.2
  * fixes a rounding error issue in the "lazy" clustering strategies
    that, in rare cases, caused infinite loops or crashes
  * adds a check on clustering's internal consistency; a failure will
    throw a new "InternalError" exception (derived from Error)
  * fixes a bug in the extraction of the fjcore code that resulted in
    fjcore failing for high multiplicities (~1000). This issue only
    affects fjcore, not the full fastjet library
* Mon Jan 12 2015 p.drouand@gmail.com
- Update to version 3.1.1
  + fix to area support for Filter with Cambridge/Aachen jets and subjets
  + GridMedianBackgroundEstimator has new constructor and RectangularGrid
    as public base
  + added virtual destructor to TilingBase class
* Fri Dec  6 2013 badshah400@gmail.com
- Initial version
